Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var KeyringContextKey struct{}
KeyringContextKey is the key used to store the keyring in the context. The keyring must be wrapped using the KeyringImpl.
Functions ¶
Types ¶
type Keyring ¶
type Keyring interface {
// List returns the names of all keys stored in the keyring.
List() ([]string, error)
// LookupAddressByKeyName returns the address of the key with the given name.
LookupAddressByKeyName(name string) ([]byte, error)
// GetPubKey returns the public key of the key with the given name.
GetPubKey(name string) (cryptotypes.PubKey, error)
// Sign signs the given bytes with the key with the given name.
Sign(name string, msg []byte, signMode signingv1beta1.SignMode) ([]byte, error)
}
Keyring is an interface used for signing transactions. It aims to be simplistic and easy to use.
type KeyringImpl ¶
type KeyringImpl struct {
// contains filtered or unexported fields
}
func NewKeyringImpl ¶
func NewKeyringImpl(k Keyring) *KeyringImpl
func (*KeyringImpl) GetPubKey ¶
func (k *KeyringImpl) GetPubKey(name string) (types.PubKey, error)
GetPubKey implements Keyring.
func (*KeyringImpl) LookupAddressByKeyName ¶
func (k *KeyringImpl) LookupAddressByKeyName(name string) ([]byte, error)
LookupAddressByKeyName implements Keyring.
func (*KeyringImpl) Sign ¶
func (k *KeyringImpl) Sign(name string, msg []byte, signMode signingv1beta1.SignMode) ([]byte, error)
Sign implements Keyring.
Click to show internal directories.
Click to hide internal directories.